import type { ParserOptions as ParserOpts } from "@babel/parser";
export type { ParserOpts };
/**
 * These are the options that 'babel-template' actually accepts and typechecks
 * when called. All other options are passed through to the parser.
 */
export declare type PublicOpts = {
    /**
     * A set of placeholder names to automatically accept, ignoring the given
     * pattern entirely.
     *
     * This option can be used when using %%foo%% style placeholders.
     */
    placeholderWhitelist?: Set<string>;
    /**
     * A pattern to search for when looking for Identifier and StringLiteral
     * nodes that can be replaced.
     *
     * 'false' will disable placeholder searching entirely, leaving only the
     * 'placeholderWhitelist' value to find replacements.
     *
     * Defaults to /^[_$A-Z0-9]+$/.
     *
     * This option can be used when using %%foo%% style placeholders.
     */
    placeholderPattern?: RegExp | false;
    /**
     * 'true' to pass through comments from the template into the resulting AST,
     * or 'false' to automatically discard comments. Defaults to 'false'.
     */
    preserveComments?: boolean;
    /**
     * 'true' to use %%foo%% style placeholders, 'false' to use legacy placeholders
     * described by placeholderPattern or placeholderWhitelist.
     * When it is not set, it behaves as 'true' if there are syntactic placeholders,
     * otherwise as 'false'.
     */
    syntacticPlaceholders?: boolean | null;
};
export declare type TemplateOpts = {
    parser: ParserOpts;
    placeholderWhitelist?: Set<string>;
    placeholderPattern?: RegExp | false;
    preserveComments?: boolean;
    syntacticPlaceholders?: boolean;
};
export declare function merge(a: TemplateOpts, b: TemplateOpts): TemplateOpts;
export declare function validate(opts: unknown): TemplateOpts;
export declare type PublicReplacements = {
    [x: string]: unknown;
} | Array<unknown>;
export declare type TemplateReplacements = {
    [x: string]: unknown;
} | void;
export declare function normalizeReplacements(replacements: unknown): TemplateReplacements;
//# sourceMappingURL=options.d.ts.map